
cd "C:\Users\alejo\Dropbox\Teaching\Malta\Data\PWT\"
use PWT, replace

* calculate real GDP per capita and its log:
gen GDPpc = rgdpe/pop
gen lnGDPpc = ln(GDPpc)

* calculate capital/output ratio:
gen K_Y = cn/rgdpe

* calculate consumption per capita and its log:
gen Cpc = ccon/pop
gen lnCpc = ln(Cpc)

preserve

keep if year==2017

l GDPpc if countrycode=="USA"

* Calculating Real GDP per capita relative to the U.S.
gen relGDPpc = GDPpc/56153.42
* Distribution of GDP per capital rel. to the U.S in 2017
histogram relGDPpc, bin(10) percent name(Hist_relGDPpc,replace)
summ relGDPpc, d


table region, c(mean GDPpc)
table region, c(mean relGDPpc)

* Plotting GDPpc and Consumption per capita
twoway (scatter lnGDPpc lnCpc, mlabel(countrycode) name(Scatter_GDPpcCpc,replace)) (lfit lnGDPpc lnCpc) 
*name(scatter1,replace)

* Plotting relative GDPpc and Total Factor Productivity
twoway (scatter relGDPpc ctfp, mlabel(countrycode) name(Scatter_relGDPTFP,replace)) (lfit relGDPpc ctfp) 
restore

preserve
keep if year==1960 | year==1980 | year==2000 | year==2017

* Plotting the evolution of the distribution of ln real GDP pc over time
twoway (kdensity lnGDPpc if year==1960) (kdensity lnGDPpc if year==1980) (kdensity lnGDPpc if year==2000) (kdensity lnGDPpc if year==2017), name(density1,replace)

* Distribution weighted by each country's population
twoway (kdensity lnGDPpc if year==1960 [w=pop]) (kdensity lnGDPpc if year==1980 [w=pop]) (kdensity lnGDPpc if year==2000 [w=pop]) (kdensity lnGDPpc if year==2017 [w=pop]), name(density2,replace)

restore

preserve
keep if year==1960 | year==2017

sort countrycode year

* Calculating average growth rate of GDPpc between 1960 and 2017
by countrycode: gen grate = exp( (lnGDPpc[_n]-lnGDPpc[_n-1])/(2017-1960)) - 1
egen grate2 = mean(grate), by(countrycode)

summ grate2 if year==1960,d

histogram grate2 if year==1960, bin(10) percent name(Hist_GDPpcgrowthrate,replace)

twoway (scatter grate2 lnGDPpc if year==1960, mlabel(countrycode) name(Scatter_convergence,replace)) (lfit grate2 lnGDPpc if year==1960)

* Estimating convergence regression:
reg grate2 lnGDPpc if year==1960,r
reg grate2 lnGDPpc if year==1960 & incomelevelname=="High income",r

twoway (scatter grate2 lnGDPpc if year==1960 & incomelevelname=="High income", mlabel(countrycode) name(Scatter_convergence2,replace)) (lfit grate2 lnGDPpc if year==1960 & incomelevelname=="High income")
